==> erp5.recipe.zope2instance-1.3.1.tar.gz: erp5.recipe.zope2instance-1.3.1/src/erp5/recipe/zope2instance/__init__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2009 Nexedi SARL and Contributors. All Rights Reserved.
# Copyright (c) 2006-2008 Zope Corporation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
import os, shutil, sys
import zc.buildout
import plone.recipe.zope2instance

class Recipe(plone.recipe.zope2instance.Recipe):
    def install(self):
        # Override plone.recipe.zope2instance so as to prepare several
        # directories used by ERP5.
        options = self.options
        location = options['location']

        requirements, ws = self.egg.working_set()
        ws_locations = [d.location for d in ws]

        if os.path.exists(location):
            shutil.rmtree(location)

        # What follows is a bit of a hack because the instance-setup mechanism
        # is a bit monolithic. We'll run mkzopeinstance and then we'll
        # patch the result. A better approach might be to provide independent
        # instance-creation logic, but this raises lots of issues that
        # need to be stored out first.
        if not self.zope2_location:
            mkzopeinstance = os.path.join(
                options['bin-directory'], 'mkzopeinstance')
            if not mkzopeinstance:
                # EEE
                return

        else:
            mkzopeinstance = os.path.join(
                self.zope2_location, 'bin', 'mkzopeinstance.py')
            if not os.path.exists(mkzopeinstance):
                mkzopeinstance = os.path.join(
                    self.zope2_location, 'utilities', 'mkzopeinstance.py')
            if sys.platform[:3].lower() == "win":
                mkzopeinstance = '"%s"' % mkzopeinstance

        if not mkzopeinstance:
            # EEE
            return

        assert os.spawnl(
            os.P_WAIT, os.path.normpath(options['executable']),
            zc.buildout.easy_install._safe_arg(options['executable']),
            mkzopeinstance, '-d',
            zc.buildout.easy_install._safe_arg(location),
            '-u', options['user'],
            ) == 0

        # patch begin: create several directories and symlinks for ERP5
        base_dir = self.buildout['buildout']['directory']
        var_dir = options.get('var', os.path.join(base_dir, 'var'))
        if not os.path.exists(var_dir):
            os.mkdir(var_dir)
        for directory in ('Constraint', 'Document', 'Extensions',
                          'PropertySheet', 'tests'):
            real_path = os.path.join(var_dir, directory)
            if not os.path.exists(real_path):
                os.mkdir(real_path)
            link_path = os.path.join(location, directory)
            if os.path.exists(link_path) and not os.path.islink(link_path):
                shutil.rmtree(link_path)
            if not os.path.exists(link_path):
                os.symlink(real_path, link_path)
        for directory in ('bt5',):
            path = os.path.join(location, directory)
            if os.path.exists(path) and not os.path.islink(path):
                shutil.rmtree(path)
            if not os.path.exists(path):
                os.symlink(os.path.join('..', directory), path)
        # patch end: create several directories and a symlink for ERP5

        try:
            # Save the working set:
            open(os.path.join(location, 'etc', '.eggs'), 'w').write(
                '\n'.join(ws_locations))

            # Make a new zope.conf based on options in buildout.cfg
            self.build_zope_conf()

            # Patch extra paths into binaries
            self.patch_binaries(ws_locations)

            # Install extra scripts
            self.install_scripts()

            # Add zcml files to package-includes
            self.build_package_includes()
        except:
            # clean up
            if os.path.exists(location):
                shutil.rmtree(location)
            raise

        return location

==> erp5.recipe.zope2instance-2.0.1.tar.gz: erp5.recipe.zope2instance-2.0.1/src/erp5/recipe/zope2instance/__init__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2010 Nexedi SARL and Contributors. All Rights Reserved.
# Copyright (c) 2006-2008 Zope Corporation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
import os, shutil
import pkg_resources
import plone.recipe.zope2instance
from plone.recipe.zope2instance import make

class Recipe(plone.recipe.zope2instance.Recipe):
    def install(self, update=False):
        # Override plone.recipe.zope2instance so as to prepare several
        # directories used by ERP5.
        options = self.options
        location = options['location']

        if not update:
            if os.path.exists(location):
                shutil.rmtree(location)

            # Which Zope2 version do we have?
            dist = pkg_resources.get_distribution('Zope2')
            parsed = dist.parsed_version
            major, minor = parsed[0:2]
            major, minor = int(major), int(minor)
            # We only support creating instances for 2.12 and 2.13
            if minor > 13:
                minor = 13
            version = str(major) + str(minor)
            make.make_instance(options.get('user', None), location, version)

        # patch begin: create several directories and symlinks for ERP5
        base_dir = self.buildout['buildout']['directory']
        var_dir = options.get('var', os.path.join(base_dir, 'var'))
        if not os.path.exists(var_dir):
            os.mkdir(var_dir)
        for directory in ('Constraint', 'Document', 'Extensions',
                          'Products', 'PropertySheet', 'tests'):
            real_path = os.path.join(var_dir, directory)
            if not os.path.exists(real_path):
                os.mkdir(real_path)
            link_path = os.path.join(location, directory)
            if os.path.exists(link_path) and not os.path.islink(link_path):
                shutil.rmtree(link_path)
            if not os.path.exists(link_path):
                os.symlink(real_path, link_path)
        for directory in ('bt5',):
            real_path = os.path.join(location, '..', directory)
            if not os.path.exists(real_path):
                os.mkdir(real_path)
            path = os.path.join(location, directory)
            if os.path.exists(path) and not os.path.islink(path):
                shutil.rmtree(path)
            if not os.path.exists(path):
                os.symlink(real_path, path)
        # patch end: create several directories and symlinks for ERP5

        try:
            # Make a new zope.conf based on options in buildout.cfg
            self.build_zope_conf()

            # Install extra scripts
            self.install_scripts()

            # Add zcml files to package-includes
            self.build_package_includes()
        except:
            # clean up
            if os.path.exists(location):
                shutil.rmtree(location)
            raise

        return location
